==> servicecatalog-1.42.1-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnLaunchTemplateConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::LaunchTemplateConstraint`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.5.0 (build 46538f8)", date = "2020-06-01T16:52:35.049Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.CfnLaunchTemplateConstraintProps")
@software.amazon.jsii.Jsii.Proxy(CfnLaunchTemplateConstraintProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnLaunchTemplateConstraintProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    @org.jetbrains.annotations.NotNull java.lang.String getPortfolioId();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    @org.jetbrains.annotations.NotNull java.lang.String getProductId();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    @org.jetbrains.annotations.NotNull java.lang.String getRules();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.String getAcceptLanguage() {
        return null;
    }

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    public static final class Builder {
        private java.lang.String portfolioId;
        private java.lang.String productId;
        private java.lang.String rules;
        private java.lang.String acceptLanguage;
        private java.lang.String description;

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getPortfolioId}
         * @param portfolioId `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder portfolioId(java.lang.String portfolioId) {
            this.portfolioId = portfolioId;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getProductId}
         * @param productId `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder productId(java.lang.String productId) {
            this.productId = productId;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getRules}
         * @param rules `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder rules(java.lang.String rules) {
            this.rules = rules;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getAcceptLanguage}
         * @param acceptLanguage `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder acceptLanguage(java.lang.String acceptLanguage) {
            this.acceptLanguage = acceptLanguage;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getDescription}
         * @param description `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLaunchTemplateConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnLaunchTemplateConstraintProps build() {
            return new Jsii$Proxy(portfolioId, productId, rules, acceptLanguage, description);
        }
    }

    /**
     * An implementation for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnLaunchTemplateConstraintProps {
        private final java.lang.String portfolioId;
        private final java.lang.String productId;
        private final java.lang.String rules;
        private final java.lang.String acceptLanguage;
        private final java.lang.String description;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.portfolioId = this.jsiiGet("portfolioId", java.lang.String.class);
            this.productId = this.jsiiGet("productId", java.lang.String.class);
            this.rules = this.jsiiGet("rules", java.lang.String.class);
            this.acceptLanguage = this.jsiiGet("acceptLanguage", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String portfolioId, final java.lang.String productId, final java.lang.String rules, final java.lang.String acceptLanguage, final java.lang.String description) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.portfolioId = java.util.Objects.requireNonNull(portfolioId, "portfolioId is required");
            this.productId = java.util.Objects.requireNonNull(productId, "productId is required");
            this.rules = java.util.Objects.requireNonNull(rules, "rules is required");
            this.acceptLanguage = acceptLanguage;
            this.description = description;
        }

        @Override
        public java.lang.String getPortfolioId() {
            return this.portfolioId;
        }

        @Override
        public java.lang.String getProductId() {
            return this.productId;
        }

        @Override
        public java.lang.String getRules() {
            return this.rules;
        }

        @Override
        public java.lang.String getAcceptLanguage() {
            return this.acceptLanguage;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("portfolioId", om.valueToTree(this.getPortfolioId()));
            data.set("productId", om.valueToTree(this.getProductId()));
            data.set("rules", om.valueToTree(this.getRules()));
            if (this.getAcceptLanguage() != null) {
                data.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicecatalog.CfnLaunchTemplateConstraintProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnLaunchTemplateConstraintProps.Jsii$Proxy that = (CfnLaunchTemplateConstraintProps.Jsii$Proxy) o;

            if (!portfolioId.equals(that.portfolioId)) return false;
            if (!productId.equals(that.productId)) return false;
            if (!rules.equals(that.rules)) return false;
            if (this.acceptLanguage != null ? !this.acceptLanguage.equals(that.acceptLanguage) : that.acceptLanguage != null) return false;
            return this.description != null ? this.description.equals(that.description) : that.description == null;
        }

        @Override
        public int hashCode() {
            int result = this.portfolioId.hashCode();
            result = 31 * result + (this.productId.hashCode());
            result = 31 * result + (this.rules.hashCode());
            result = 31 * result + (this.acceptLanguage != null ? this.acceptLanguage.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            return result;
        }
    }
}

==> servicecatalog-1.43.0-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnLaunchTemplateConstraintProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::LaunchTemplateConstraint`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.6.0 (build 248e75b)", date = "2020-06-04T00:02:09.786Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.CfnLaunchTemplateConstraintProps")
@software.amazon.jsii.Jsii.Proxy(CfnLaunchTemplateConstraintProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnLaunchTemplateConstraintProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-portfolioid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPortfolioId();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-productid
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getProductId();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-rules
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getRules();

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAcceptLanguage() {
        return null;
    }

    /**
     * `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-launchtemplateconstraint.html#cfn-servicecatalog-launchtemplateconstraint-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnLaunchTemplateConstraintProps> {
        private java.lang.String portfolioId;
        private java.lang.String productId;
        private java.lang.String rules;
        private java.lang.String acceptLanguage;
        private java.lang.String description;

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getPortfolioId}
         * @param portfolioId `AWS::ServiceCatalog::LaunchTemplateConstraint.PortfolioId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder portfolioId(java.lang.String portfolioId) {
            this.portfolioId = portfolioId;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getProductId}
         * @param productId `AWS::ServiceCatalog::LaunchTemplateConstraint.ProductId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder productId(java.lang.String productId) {
            this.productId = productId;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getRules}
         * @param rules `AWS::ServiceCatalog::LaunchTemplateConstraint.Rules`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder rules(java.lang.String rules) {
            this.rules = rules;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getAcceptLanguage}
         * @param acceptLanguage `AWS::ServiceCatalog::LaunchTemplateConstraint.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder acceptLanguage(java.lang.String acceptLanguage) {
            this.acceptLanguage = acceptLanguage;
            return this;
        }

        /**
         * Sets the value of {@link CfnLaunchTemplateConstraintProps#getDescription}
         * @param description `AWS::ServiceCatalog::LaunchTemplateConstraint.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnLaunchTemplateConstraintProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnLaunchTemplateConstraintProps build() {
            return new Jsii$Proxy(portfolioId, productId, rules, acceptLanguage, description);
        }
    }

    /**
     * An implementation for {@link CfnLaunchTemplateConstraintProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnLaunchTemplateConstraintProps {
        private final java.lang.String portfolioId;
        private final java.lang.String productId;
        private final java.lang.String rules;
        private final java.lang.String acceptLanguage;
        private final java.lang.String description;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.portfolioId = this.jsiiGet("portfolioId", java.lang.String.class);
            this.productId = this.jsiiGet("productId", java.lang.String.class);
            this.rules = this.jsiiGet("rules", java.lang.String.class);
            this.acceptLanguage = this.jsiiGet("acceptLanguage", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String portfolioId, final java.lang.String productId, final java.lang.String rules, final java.lang.String acceptLanguage, final java.lang.String description) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.portfolioId = java.util.Objects.requireNonNull(portfolioId, "portfolioId is required");
            this.productId = java.util.Objects.requireNonNull(productId, "productId is required");
            this.rules = java.util.Objects.requireNonNull(rules, "rules is required");
            this.acceptLanguage = acceptLanguage;
            this.description = description;
        }

        @Override
        public java.lang.String getPortfolioId() {
            return this.portfolioId;
        }

        @Override
        public java.lang.String getProductId() {
            return this.productId;
        }

        @Override
        public java.lang.String getRules() {
            return this.rules;
        }

        @Override
        public java.lang.String getAcceptLanguage() {
            return this.acceptLanguage;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("portfolioId", om.valueToTree(this.getPortfolioId()));
            data.set("productId", om.valueToTree(this.getProductId()));
            data.set("rules", om.valueToTree(this.getRules()));
            if (this.getAcceptLanguage() != null) {
                data.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-servicecatalog.CfnLaunchTemplateConstraintProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnLaunchTemplateConstraintProps.Jsii$Proxy that = (CfnLaunchTemplateConstraintProps.Jsii$Proxy) o;

            if (!portfolioId.equals(that.portfolioId)) return false;
            if (!productId.equals(that.productId)) return false;
            if (!rules.equals(that.rules)) return false;
            if (this.acceptLanguage != null ? !this.acceptLanguage.equals(that.acceptLanguage) : that.acceptLanguage != null) return false;
            return this.description != null ? this.description.equals(that.description) : that.description == null;
        }

        @Override
        public int hashCode() {
            int result = this.portfolioId.hashCode();
            result = 31 * result + (this.productId.hashCode());
            result = 31 * result + (this.rules.hashCode());
            result = 31 * result + (this.acceptLanguage != null ? this.acceptLanguage.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            return result;
        }
    }
}
